{% extends 'spire/authentication/page/authentication_page.html' %}

{% load static %}

{% load crispy_forms_filters %}

{% block base_title %} Password Reset {% endblock %}

{% block authentication_page_content %}
    <h3>Password Reset</h3>
    <div class="py-2">You have successfully changed your password!</div>
    <a href="{% url 'user_account_login' %}"><button class="d-block mx-auto w-100 btn btn-app-primary bg-app-primary mt-2">Login</button></a>
{% endblock %}