# Generated by Django 5.2 on 2025-04-11 21:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('spire_ai', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='aiinteraction',
            name='run_time_seconds',
            field=models.FloatField(default=0.0),
        ),
        migrations.AlterField(
            model_name='aiusage',
            name='run_time_seconds',
            field=models.FloatField(default=0.0),
        ),
    ]
