# Generated by Django 5.2 on 2025-04-14 15:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('spire_ai', '0002_alter_aiinteraction_run_time_seconds_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='aiusage',
            name='was_successful',
            field=models.BooleanField(default=True, verbose_name='Success'),
        ),
        migrations.AlterField(
            model_name='aiinteraction',
            name='event_count',
            field=models.IntegerField(default=0, verbose_name='Events'),
        ),
        migrations.AlterField(
            model_name='aiinteraction',
            name='run_time_seconds',
            field=models.FloatField(default=0.0, verbose_name='Run Time'),
        ),
        migrations.AlterField(
            model_name='aiinteraction',
            name='token_usage',
            field=models.IntegerField(default=0, verbose_name='Tokens'),
        ),
        migrations.AlterField(
            model_name='aiinteraction',
            name='was_successful',
            field=models.BooleanField(default=True, verbose_name='Success'),
        ),
        migrations.AlterField(
            model_name='aiusage',
            name='event_count',
            field=models.IntegerField(default=0, verbose_name='Events'),
        ),
        migrations.AlterField(
            model_name='aiusage',
            name='run_time_seconds',
            field=models.FloatField(default=0.0, verbose_name='Run Time'),
        ),
        migrations.AlterField(
            model_name='aiusage',
            name='token_usage',
            field=models.IntegerField(default=0, verbose_name='Tokens'),
        ),
    ]
