# Generated by Django 5.2 on 2025-04-14 15:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('spire_ai_chat', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='chat',
            options={'ordering': ('-last_message_datetime', 'name'), 'verbose_name': 'Chat', 'verbose_name_plural': 'Chats'},
        ),
    ]
