{% load json %}

<input type="hidden" name="{{ widget.name }}" value='{{ widget.value }}'>

<script src="//unpkg.com/alpinejs" defer></script>

<style>
    .key-text {
        color: #417690;
    }
</style>

<div class="row" style="font-family: monospace; margin-left: -17px;">
    {% include 'spire/ai/forms/elements/dict_element.html' with dict=interaction_dict open_dropdowns=False %}
</div>
