{% extends 'spire/card/title_card.html' %}

{% block card_title %}
	SpireChildApp
{% endblock %}

{% block card_title_content %}
	{% include 'spireparentapp/spirechildapp/form/spirechildapp_form.html' %}
{% endblock %}
