{% extends "spire/notification/app/dropdown/notification_dropdown.html" %}

{% block notification_dropdown_trigger %}
    <i x-bind='trigger' class="bi bi-bell-fill fs-4 cursor-pointer position-absolute"></i>
    <span style="width: 10; height: 10px; top: -1px; right: -24px;" class="bg-danger rounded-circle d-flex position-absolute"></span>
{% endblock %}
