<div x-data="{
        init() {
            this.response_message.render_outer($refs.loading_response_message)
        },
        response_message: new ViewGlue('{% url "spire_ai:chat:render:response_message" %}', {
            message_body: '{{ body|escapejs }}',
            chat_id: '{{ chat_id }}'
        })
    }">
    <div x-ref="loading_response_message" x-init="$el.scrollIntoView()" class="row mt-2">
        <div class="col-auto">
            <div class="spinner-border text-app-primary" role="status">
                <span class="visually-hidden">Loading...</span>
            </div>
        </div>
        <div class="col">
        </div>
    </div>

</div>


